from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x07\x00\x42\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x7b\x08\x00\x00\x00\x00\x00\x18\x03\xf2\x2a\x04\x07\xec\xd6\x8a\xa2\x89\xba\x9d\xd0\x79\x2f\xb4\x00\x00\x00\x00\x00\x00\x00\x00\x35\xed\x32\xab\x35\x92\x0c\x89\xb5\xc4\xcf\x6b\x14\x3f\xf0\xcf\xe5\xfe\x58\x8a\x88\xd9\xb6\x89\x71\xdd\x88\xc0\xd5\xb7\x8d\xc4\x8a\xe2\x6f\x7e\xb3\xd0\x64\x1e\x6c\x7d\xd0\x02\x7d\x51\x92\xdd\x47\xc4\x4e\x18\x51\x78\xa0\x54\xf4\x84\xe8\xb0\xec\x1f\x6e\x27\x72\xaf\x3c\xa7\x94\xbd\x20\x13\x68\x8a\x83\xa0\x57\x62\x91\x24\xc6\xe6\x49\x7d\xeb\x15\x5c\x39\x3c\xfa\x54\x8c\x89\xec\xc0\xf0\x4a\xac\xa5\x73\x59\x8b\xbb\x4f\xe0\xb2\xd3\xc8\xb0\x77\x86\x61\x37\xc0\x04\x26\x94\x3d\x9b\x4e\xc9\xd3\xaa\x4e\x30\x32\xbe\x75\xc3\x9e\xe8\xa0\xac\xcf\xb4\xcb\x36\x8f\xa9\x93\xc9\xa9\xbc\xe9\x1a\x3b\xf3\x53\x45\x68\xd6\x15\x6a\x89\x83\x2e\x8e\x82\x6f\x25\x13\xe4\x61\x42\x3e\x61\xa9\xd1\xcc\x54\x99\xfc\xe9\x62\xcf\x44\x15\xed\x5d\x1d\xcd\x10\x3c\x97\x84\x67\x2c\x53\x73\xc9\xa4\x25\x4b\xc9\xa0\xf5\xb5\x7c\x05\x59\x73\xf6\xa7\xdb\xdc\x45\x57\xd6\xe9\xfa\x3a\x4d\x6d\x04\xe9\x9a\x48\xf9\xe2\xc6\xe0\x22\xe6\xdd\xda\x2b\x4a\x22\x8e\x1d\x20\xf2\xcc\xbd\xa8\xec\x6e\x07\x18\x48\xb2\xa4\xaa\x88\xce\x17\x3f\xf7\x50\xdd\x54\x50\x88\xc9\x4b\x9b\xec\x7d\x16\x04\x8f\x4b\x8c\xa0\x71\x53\x50\x2e\xfa\x5c\x6b\xec\xaf\x70\xd7\x4b\x27\x87\x31\x0a\xc3\x9f\x9e\x65\x0f\x98\x00\x1c\x0d\xdc\xf2\x2d\xc2\x66\x1a\x0c\xf9\x36\xdd\xb1\xbd\xcd\x23\xb4\x20\xc8\x2e\xf4\x2d\x24\x24\x06\x32\x15\x8a\x7d\xef\x0b\x0a\xc8\x4b\x7d\x17\x1e\x6c\xe1\x03\x2e\xba\x30\x92\xc3\xce\x87\x6a\x4d\x03\xf0\xaf\x55\x33\x42\xed\xba\xaf\x53\xcd\xa9\xac\x14\xa7\x23\x55\x44\xe1\xbb\x96\x61\xe5\xfd\x42\x7d\x20\xbe\x18\x09\x89\x16\x74\x42\xc4\x9d\x01\x86\x27\x2b\xa1\xa4\xf1\x8e\xc7\x65\x86\x0c\x81\x25\x9d\xf8\x78\x87\xa0\x1b\x3e\xf9\xa5\x4a\xd5\xa4\x5d\x58\x4c\xb2\x59\x4d\xc5\xc3\x25\x1c\xc7\x5c\x9c\xe4\x3e\x31\xd6\x9e\x32\x2a\x5a\xa2\xdc\x6c\xd4\xd2\x3c\x48\xa6\xf2\xb3\x8a\x8b\xea\x6e\xc8\x91\xab\x71\x47\xaa\xa8\xd9\xd6\xa6\xc3\xdc\xa9\x07\xda\x0b\x75\xeb\x05\x67\x95\x7a\x91\xb1\xf1\xf7\xfb\xf4\xfa\x9f\x74\x86\xcc\xfe\xc4\xd4\xbf\x01\x99\xd7\xf0\x46\x79\x9e\xdb\xd5\x1f\x3f\xbd\x97\x99\x48\x01\xe3\x9a\xdf\x44\x1e\x87\x40\xaa\x5d\x68\xc1\xcb\x0d\x9a\xb7\x41\x02\x64\x09\x77\xaf\x7b\x75\x90\x75\x6e\xd8\x89\x59\xf8\x8f\x93\x7f\x82\xeb\x61\x31\xc6\x90\x7b\xb5\x3d\xad\xfd\x6f\x9a\x62\xa6\xb1\xd1\x63\xd3\x86\x73\x35\x26\x5c\xfd\x93\x99\x89\xe4\x0b\xc6\x55\x67\xdc\x7d\x33\x7a\x11\xbd\x52\x3a\xb4\xea\x52\xa6\xcb\x7e\x74\x96\x0b\x9d\xd4\xdb\xe9\xbf\x62\xf3\xcf\x15\x1f\x9d\x75\xa8\xf8\x40\x6f\x3e\x3e\x81\x5e\x27\x95\xf3\x39\xd1\xba\x84\x8c\x4c\x87\x71\xbd\x79\x7a\x6f\xe9\x1f\xcf\xc6\xc6\x6a\x98\x94\xb1\x6a\x4f\x34\xd5\xa5\x64\x7c\xc4\x71\xa0\x22\xf5\x6e\x66\xb7\x9e\x69\x02\xac\x55\xae\x7d\x23\x92\xd4\xf0\x06\x9c\x26\x6e\x58\x17\xb7\x5c\x63\xb3\x8a\xea\x0b\xb6\x39\x54\x04\x97\xfa\xc3\x0e\x13\xa6\xf4\x8e\xf2\x48\x86\xae\xfe\xee\xed\x65\x54\x13\x9f\x5a\xee\xd3\x2b\x17\xca\xb6\x35\x47\xeb\x5d\xff\x42\x9b\xe9\x4f\x5b\x73\xaf\x30\xfe\x39\x4f\xa5\x17\x14\xbf\x2d\x95\xd8\xdb\xdd\x01\x92\x26\x65\x67\xf4\x7c\xf0\xdf\x5c\xaf\xe1\xb0\xcb\xce\x93\x65\xa5\x2e\x8c\x4d\xae\x55\x49\xfc\x46\xdb\x06\x6a\xe0\x34\x8c\x25\x9f\x37\x28\x4e\x9b\xa1\x3d\x73\x45\x3d\xa6\x4e\x61\xa7\x92\x8e\xfa\x6b\xdc\xc6\xcb\xd3\x8d\x7f\xae\x1c\x3e\x6a\xcf\xbf\x79\x39\x31\x74\xef\x88\x4a\x20\x4c\x8b\xd2\x97\x71\x95\x27\x7f\x44\x68\xcb\xff\xb7\xd3\x2b\x03\xd2\xfc\x5e\xb1\x35\xcc\xbe\xbe\x51\x1b\x06\x02\x28\x7d\x18\xa5\xe2\xfa\x04\xf0\x35\x4c\x71\x07\x3d\x57\xbc\xef\x1e\x05\x1b\x61\xd5\xc1\x03\x63\x6a\xed\x78\x9e\x23\x8d\x7e\x95\xae\xba\xf1\xd4\xb3\x2e\xd3\x93\xad\x6b\x34\xb8\x4b\x5e\x93\x6a\xec\x8f\x05\x70\x68\xa9\x37\x6d\x52\x6b\x25\xa6\xb0\x9e\x0a\x9a\xbd\xc1\xb7\x65\x8e\x62\xd9\x33\xe5\x94\xf1\xbb\x2c\x02\xab\x1f\x2b\xe9\x65\xd3\x9f\xd7\xb3\x6a\x1e\xa6\x32\x67\x12\xba\xe6\x7a\xa2\x21\x56\xaa\x4b\xd5\xdc\x82\x55\x83\xf5\x38\xde\xd3\x95\xa2\xbc\x6a\x42\x8a\x9a\x9a\xbe\xb6\xbb\xfd\x26\x16\x42\xd0\xf3\xfe\x6a\x1f\xa5\xf6\x2a\x6f\xbf\x3b\x20\x87\x98\xed\x24\xeb\x0b\x25\x63\x03\x22\x6e\x0c\x07\x85\xfc\x86\xf5\x98\xa9\xb7\x79\xa3\x59\x88\x56\x54\x90\x41\xd1\xfa\x10\xed\x7f\x01\xbc\x39\xc4\x52\x07\xf7\x4b\x30\x38\x1c\xd5\xdf\xf8\x98\x0c\xca\xa1\x48\xbf\x10\x2d\x64\x11\x8e\x2c\x16\x61\x22\x39\xb6\x4a\x7c\xe8\x16\x34\xdd\xf9\xe5\xc4\xd5\xb1\x38\x34\xf9\x14\x76\xfc\x59\xc8\x9d\x73\xa1\x1d\x07\xc8\x1f\x81\xb9\x65\x62\x2e\x6b\x4d\xb7\xd6\x4d\xb3\xe1\x81\xb5\xd4\xda\x56\xf7\x7b\x87\x31\x27\xda\x0b\x5c\x96\x21\x25\x7a\x10\xf8\x1c\xf7\x6f\x08\x06\x7c\x49\xff\xc6\xdb\x4a\x06\x8d\x88\xd4\xeb\xbf\xaa\xe8\x62\x6b\x32\x11\x61\x22\xda\x58\x0c\x34\x39\x6e\x3e\xf9\x44\x9e\x27\xc3\x12\x64\x80\x67\xdf\x43\x73\x00\xaf\xa7\xb0\xb8\x48\xd5\xfa\xde\xd8\x08\x82\xee\x79\xa3\x0e\x45\x2c\xb6\x17\x37\x0d\x8a\x0a\x13\xd6\x1b\xee\xc0\xe2\x3f\x08\x09\xec\xc8\xec\x54\x07\x86\x1f\xb9\x5f\x7e\x93\x39\xb7\xc0\x9c\xb9\x3f\x1e\x1e\x47\x41\x49\xc4\x9b\x31\x4d\xbc\x20\xd9\xee\xe4\x9b\x51\x79\x20\x24\x4b\x11\x4d\x0f\x23\xd7\xc7\xc6\xe1\x78\xbb\x1b\x8e\x2d\xbc\x03\xc5\x4c\x53\x68\x54\x74\xf5\x79\xc7\x96\x3b\xa2\x10\xee\xd3\xb9\x4f\xc9\xd3\xa9\xb5\xde\x4a\x8e\x26\x01\xd4\xf6\x93\x4f\x0a\x7c\xe2\x21\x4d\x8f\x41\x7e\x50\x0a\x13\x74\x7b\xb8\xdd\xd5\x6b\xb4\x09\xbc\x0c\x27\x57\x9f\xbb\x27\x41\x9f\xf8\x5b\xe6\x5e\x8b\x84\x7a\x2a\x65\xc8\xf1\xb2\xc8\x0a\x8c\x04\x25\xec\x83\x58\x00\xad\xf9\x93\xc9\xa4\x11\xe4\x31\xd2\xe9\x5c\x43\x47\xf4\x78\xc1\x9c\x00\x36\x39\x31\xfc\xb5\x21\x1d\xcf\x42\xb6\x59\xfe\xde\xb9\x2b\x5b\xb0\x8b\x17\xf7\x07\x9e\xdb\x3d\x73\x86\x30\xeb\xdb\x0d\x4b\x97\x04\x94\x10\xe3\x82\x2c\x90\x52\x15\x54\x90\x7d\xec\x2e\xa9\x85\x12\xa1\x10\xcb\xd0\x18\xae\xe3\xcb\x3d\xea\x09\x7b\xde\x32\x52\x32\x4b\x22\x96\x7d\xb1\x3b\x6b\x55\x60\x10\x32\x23\xa6\x3a\xa0\xa6\xb7\x39\xe5\x97\x2b\x80\xc6\x47\x65\x81\x1f\x2b\xb5\xb0\x0e\xae\xaf\xfd\x8c\x25\xb4\x5c\x0c\xe7\x8b\x4b\x0f\x66\x13\x02\x57\x3a\x13\x3c\x19\xfe\xd4\xa6\x9d\x73\xc8\xda\xdb\xec\xa2\xfe\x15\x5b\x01\x66\x5e\x00\xcd\xf9\xa5\xb4\xec\x44\xa5\x5c\xcf\x4c\x35\x83\x61\xfb\x22\xa5\x47\x92\xa3\x21\x5b\xf5\x22\x8f\x8c\xe5\x4b\x4c\xf4\x41\xdb\xb5\x51\xfd\xc8\x41\xd1\x96\xeb\x11\x26\x07\xd3\xd1\x32\x1d\x68\x16\x04\x8d\x2b\x74\x3c\x4d\xb9\xa0\x0e\x32\xf1\xb8\x95\xe4\x5f\x5d\x90\xa4\xb6\x3e\x20\x58\x12\x41\xaa\x27\x95\x8a\x12\x97\xcc\x19\xff\x20\xe8\x05\xb0\x3b\xa7\x4e\x1b\xbd\x12\x92\x13\x30\xdd\x10\x18\xd7\xcc\x33\xae\xe7\x71\x5a\x50\xf9\xc0\xe8\x29\x84\x68\x01\xc7\x15\xba\xf5\x38\xb9\x9d\xec\x1a\x1d\x34\x7d\xcd\xf6\xdf\xda\xac\x85\x47\x24\x70\xdb\xb3\x43\x51\x60\x6f\xba\x0b\x3c\xa3\x28\x7c\x6c\x7e\xc9\x67\x61\x9d\x8e\xe5\xc3\x3d\xf2\x7a\xb1\xed\x4e\x0a\xd9\xb3\x78\xac\xd0\x0d\x24\xfb\x0e\x6f\xc9\x91\xea\x88\x2e\x7c\x02\xd2\xae\x3f\x4f\x93\xca\x43\x41\x7e\x71\xa1\x8f\x58\x30\x48\x5a\xe5\xaf\x77\xc1\x0d\x93\xe4\xe1\x4c\x5b\x53\xd2\x90\x3d\x63\x30\xb9\x51\xc0\x24\x91\x93\x12\xb3\x81\x0b\x01\xe3\x5c\x8f\x7a\xf9\x3e\x99\xfe\x13\x75\x29\xf7\x9e\x07\x99\xb7\x1b\x6a\xfc\x87\x31\x26\xd3\x0b\x91\x75\x55\x38\x74\x6d\x56\xf6\x31\x05\x5b\x42\xb4\x66\x57\x7b\x76\x71\x97\x58\x34\x79\xab\x45\xea\x61\xa8\x23\x72\x1a\x6c\x8d\xd9\xd4\xac\x63\x4d\x6d\x45\x9c\xc2\xab\xb2\x4e\x60\x79\xed\x99\x3f\x55\x59\x4d\x1e\xb0\x54\x86\x6f\x46\xcc\x7a\x47\xeb\xf9\xe3\x59\x83\xb8\x0d\x5d\xde\xd1\xe8\x01\x28\xe0\x3b\x04\x24\xfc\x45\xae\xd6\x2e\x01\xdc\xec\x2a\xbf\x1e\xde\x42\xe7\x18\xf7\x8f\xfe\x36\x20\x57\x13\x20\xf5\x52\x92\xc7\x57\xce\x04\x6f\x44\x2d\xab\x00\x66\x1e\x46\x90\xb4\xe5\x81\x81\xba\xfb\xfd\xfb\x0e\x7c\xe1\xf1\x1e\x92\xf2\xc5\x30\x28\x41\xfe\x41\xd8\x79\x7f\x69\x21\x80\x8c\x5e\x17\xa6\xf0\xa0\x5d\xbf\x5d\xe1\xa7\x97\x3e\xde\x62\x43\xc8\x9d\x82\x46\x23\x0f\x43\xe0\xf9\x94\x7e\x09\x25\x15\xca\xf5\x63\xd4\x3f\x69\x84\x9e\x0e\xc3\x6d\x5c\x88\xe7\xdf\xa1\x3e\x56\x37\x57\x79\x14\x84\x3e\x07\x0a\x09\x29\x0a\x42\x98\x02\xad\x70\x53\xc3\xc4\x7b\xd7\x93\x38\x42\x30\xaf\xad\x4e\x0b\x82\x22\x62\x4e\x72\x8b\x14\x0f\xdc\xbc\xae\xdd\xe3\xf3\xe3\x80\xf9\x9e\x92\xaf\xd8\x90\xfe\x30\x1c\x85\x91\x0e\x69\x1c\xdd\x6e\xea\x17\xe2\x3d\x53\x95\x94\x2d\x53\x8f\x5b\x64\x3e\xde\x93\xa7\xf0\xd8\xa1\xfb\x98\xc5\x39\xae\x7c\xb5\x91\xf4\x13\xa2\x27\x11\x11\x71\xab\x4b\x2e\x55\xf4\xc8\x2b\xef\xda\x6a\x0f\x51\x3e\x47\xc0\x51\x3b\x00\x68\x80\x73\x3c\x44\x27\xdc\xf0\x8e\x5c\x1c\x39\x72\x5a\x1e\xec\x96\xd2\x47\x3a\xbf\x38\xe2\x6e\x54\x71\xac\xe1\x52\x80\xc6\x15\x14\x90\x70\xa5\x21\xd4\x52\xb5\x98\xb2\xcb\x2e\x89\xa2\x12\x78\xc5\xd4\xad\x76\xd9\xa0\xfb\x3f\xcd\x6b\x4b\x8f\x37\xd7\xe9\xf6\xb1\x9c\x93\x10\x73\x18\xbd\x5c\x1d\x9d\x91\xca\xe2\x66\x14\x03\x06\xe1\x7c\x51\xcd\xf9\xf7\xda\xcb\xd5\xe5\x58\x3d\x06\xa8\xe5\xab\xe2\x52\xa3\xbc\x12\x9f\x57\x00\xf8\x4c\x09\x2d\x46\x0e\xdc\xd2\x50\xd2\xf8\x51\xd3\xb6\xe7\xc1\x93\xd4\x34\x50\x38\x81\xdc\xd7\x4b\xc3\x78\xf7\x45\xfa\xb0\xdd\x4d\x62\x4b\xa6\xcb\x42\xb0\x6c\xe9\xc3\x97\x2f\x5b\x3e\xb6\x49\x24\x0a\x68\x8a\x87\x42\x08\xa0\xa0\xc5\xca\xf9\xbc\x06\xa7\xb1\x48\xd7\x9f\x5e\x4a\xb6\x25\xb0\x66\xb7\x8c\x81\x87\x1d\xfd\x37\x38\x56\xb2\xed\x54\x9d\x59\x31\x68\x2f\x3d\x02\xdd', 2)

# cleanup
del pyarmor_runtime

